@@ -1,11 +1,13 @@
 #!/bin/bash
+# This builds skia for MacOS (x64/arm64) amd Linux (x64/arm64)
 # Requires clang compiler
 # Linux deps:
-# sudo apt-get install -y ninja-build libharfbuzz-dev libwebp-dev
+#   sudo apt-get install -y ninja-build libharfbuzz-dev libwebp-dev fontconfig
 # Apple deps:
-# brew install bazelisk ninja harfbuzz webp
-# Run this script from to gw directory
+#   brew install bazelisk ninja harfbuzz webp
+# Run this script from gw top directory:
 #    bash ./deps/build_skia.sh
+# Skia should be ready for gw to use
 
 NAME=${PWD}/lib/skia
 echo "Skia out folder is: $NAME"
@@ -24,10 +26,10 @@ EXTRA_LDFLAGS=""
 
 # Architecture-specific flags
 if [ "$ARCH" = "x86_64" ]; then
-    EXTRA_CFLAGS='extra_cflags=["-mavx2", "-mfma", "-mavx512f", "-mavx512dq", "-msse4.2", "-mpopcnt", "-frtti"]'
+    EXTRA_CFLAGS='extra_cflags=["-mavx2", "-mfma", "-mavx512f", "-mavx512dq", "-msse4.2", "-mpopcnt", "-fno-rtti"]'
     EXTRA_LDFLAGS='extra_ldflags=["-mavx2", "-mfma", "-mavx512f", "-mavx512dq"]'
 elif [ "$ARCH" = "aarch64" ] || [ "$ARCH" = "arm64" ]; then
-    EXTRA_CFLAGS='extra_cflags=["-march=armv8-a+crc+crypto", "-frtti"]'
+    EXTRA_CFLAGS='extra_cflags=["-march=armv8-a+crc+crypto", "-fno-rtti"]'
     EXTRA_LDFLAGS='extra_ldflags=["-march=armv8-a+crc+crypto"]'
 else
     echo "Unsupported architecture: $ARCH"
@@ -41,9 +43,9 @@ if [ "$OS" = "Darwin" ]; then
     SDK_PATH="/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk"
     echo "SDK_PATH ${SDK_PATH}"
     EXTRA_CFLAGS=$(echo "$EXTRA_CFLAGS" | sed 's/\]$//')
-    EXTRA_CFLAGS+=", \"-mmacosx-version-min=10.15\", \"-isysroot\", \"${SDK_PATH}\"]"
+    EXTRA_CFLAGS+=", \"-mmacosx-version-min=10.9\", \"-isysroot\", \"${SDK_PATH}\"]"
     EXTRA_LDFLAGS=$(echo "$EXTRA_LDFLAGS" | sed 's/\]$//')
-    EXTRA_LDFLAGS+=", \"-mmacosx-version-min=10.15\", \"-isysroot\", \"${SDK_PATH}\"]"
+    EXTRA_LDFLAGS+=", \"-mmacosx-version-min=10.9\", \"-isysroot\", \"${SDK_PATH}\"]"
 
     EXTRA_ARGS="skia_use_gl=true skia_use_metal=true"
 elif [ "$OS" = "Linux" ]; then
@@ -65,7 +67,7 @@ export PATH="${PWD}/depot_tools:${PATH}"
 depot_tools/fetch skia
 
 cd skia
-VERSION=m93  #-87e8842e8c
+VERSION=m133
 git checkout origin/chrome/${VERSION}
 echo "Checked out Skia version: ${VERSION}"
 python3 tools/git-sync-deps
@@ -96,33 +98,35 @@ bin/gn args out/${REL} --list
 ninja -C out/${REL}
 
 mkdir -p ${NAME}/out/${REL}
-mkdir -p ${NAME}/third_party/externals
+#mkdir -p ${NAME}/third_party/externals
 
 cp -rf out/${REL}/* ${NAME}/out/${REL}
 cp -rf include ${NAME}
 cp -rf modules ${NAME}
-cp -rf src ${NAME}
 
-libs=( "freetype" "harfbuzz" "icu" "libpng" "zlib" )
-
-for l in "${libs[@]}"
-do
-  echo $l
-  mkdir -p ${NAME}/third_party/externals/${l}
-  cp -rf third_party/externals/${l}/src ${NAME}/third_party/externals/${l}
-  cp -rf third_party/externals/${l}/include ${NAME}/third_party/externals/${l}
-  cp -rf third_party/externals/${l}/source ${NAME}/third_party/externals/${l}
-  cp third_party/externals/${l}/*.h ${NAME}/third_party/externals/${l}
-done
-
-cp -rf third_party/icu ${NAME}/third_party
+#libs=( "freetype" "harfbuzz" "icu" "libpng" "zlib" )
+#
+#for l in "${libs[@]}"
+#do
+#  echo $l
+#  mkdir -p ${NAME}/third_party/externals/${l}
+#  cp -rf third_party/externals/${l}/src ${NAME}/third_party/externals/${l}
+#  cp -rf third_party/externals/${l}/include ${NAME}/third_party/externals/${l}
+#  cp -rf third_party/externals/${l}/source ${NAME}/third_party/externals/${l}
+#  cp third_party/externals/${l}/*.h ${NAME}/third_party/externals/${l}
+#done
+#
+#cp -rf third_party/icu ${NAME}/third_party
 
 # clean up
 cd ${NAME}
-rm -rf modules/skottie/tests
-rm -rf out/${REL}/obj
-rm -rf out/${REL}/gen
-rm -rf out/${REL}/gcc_like_host
+
+rm -rf ${NAME}/out/Release/obj
+rm -rf ${NAME}/out/Release/gen
+rm -rf ${NAME}/out/Release/*.dat
+rm -rf ${NAME}/out/Release/*.stamp
+rm -rf ${NAME}/modules/audioplayer
+
 find . -name "*.clang-format" -type f -delete
 find . -name "*.gitignore" -type f -delete
 find . -name "*.md" -type f -delete
@@ -133,6 +137,7 @@ find . -name "*.ninja.d" -type f -delete
 find . -name "*BUILD*" -type f -delete
 find . -name "*.txt" -type f -delete
 find . -name "test*" -type d -exec rm -rv {} +
+
 cd ../
 
 pwd
