@@ -24,6 +24,11 @@
 #include "include/core/SkPictureRecorder.h"
 #include "include/core/SkPicture.h"
 #include "include/svg/SkSVGCanvas.h"
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
+    #include "include/gpu/ganesh/gl/GrGLAssembleInterface.h"
+#else
+    #include "include/gpu/gl/GrGLAssembleInterface.h"
+#endif
 
 #ifdef __EMSCRIPTEN__
     #include <emscripten.h>
@@ -87,8 +92,20 @@ int main(int argc, char *argv[]) {
         plotter.setGlfwFrameBufferSize();
 
         sk_sp<const GrGLInterface> interface = GrGLMakeNativeInterface();
+        if (!interface) {
+            interface = GrGLMakeAssembledInterface(
+                    nullptr,
+                    [](void*, const char* name) -> GrGLFuncPtr {
+                        return (GrGLFuncPtr)glfwGetProcAddress(name);
+                    }
+            );
+        }
+        if (!interface) {
+            std::cerr << "Error: could not create OpenGL interface\n";
+            std::exit(-1);
+        }
 
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
         if (!interface || !interface->validate()) {
             std::cerr << "Error: skia GrGLInterface was not valid" << std::endl;
             if (!interface) {
@@ -365,7 +382,7 @@ int main(int argc, char *argv[]) {
                 sk_sp<SkImage> img;
                 if (!plotter.regions.empty()) {  // plot target regions
 
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
                     auto imageInfo = SkImageInfo::MakeN32Premul(
                             iopts.dimensions.x * plotter.monitorScale,
                             iopts.dimensions.y * plotter.monitorScale);
