@@ -35,6 +35,7 @@ namespace Parse {
         opMap["ref-end"] = REF_END;
         opMap["pnext"] = PNEXT;
         opMap["seq"] = SEQ;
+        opMap["seq-rc"] = SEQ_RC;
         opMap["seq-len"] = SEQ_LEN;
         opMap["cigar"] = CIGAR;
 
@@ -116,6 +117,7 @@ namespace Parse {
         permit[TID] = numeric_like;
         permit[MID] = numeric_like;
         permit[SEQ] = string_like;
+        permit[SEQ_RC] = string_like;
         permit[SEQ_LEN] = numeric_like;
         permit[CIGAR] = string_like;
 
@@ -328,6 +330,23 @@ namespace Parse {
         return 1;
     }
 
+    char complement(char base) {
+        switch (base) {
+            case 'A': return 'T';
+            case 'T': return 'A';
+            case 'C': return 'G';
+            case 'G': return 'C';
+            default: return 'N';
+        }
+    }
+
+    std::string reverseComplement(const std::string& dna) {
+        std::string result;
+        result.reserve(dna.size());
+        std::transform(dna.rbegin(), dna.rend(), std::back_inserter(result), complement);
+        return result;
+    }
+
     int Parser::prep_evaluations(std::vector<Eval> &evaluations, std::vector<std::string> &output) {
         if (! opMap.contains(output[0])) {
             out << "Left-hand side property not available: " << output[0] << std::endl;
@@ -347,56 +366,70 @@ namespace Parse {
         }
 
         Eval e;
-        if (lhs >= 3000 && lhs < 4000) {
+        bool is_none = (output.back() == "none" || output.back() == "''" || output.back() == "\"\"");
+
+        if (lhs >= 3000 && lhs < 4000) {  // Numeric-like
             e.property = lhs;
             e.op = mid;
-            try {
-                e.ival = std::stoi(output.back());
-            } catch (...) {
-                if (output.back() == "del" || output.back() == "deletion") {
-                    e.ival = Segs::Pattern::DEL;
-                } else if (output.back() == "inv_f" || output.back() == "inversion_forward") {
-                    e.ival = Segs::Pattern::INV_F;
-                } else if (output.back() == "inv_r" || output.back() == "inversion_reverse") {
-                    e.ival = Segs::Pattern::INV_R;
-                } else if (output.back() == "dup" || output.back() == "duplication") {
-                    e.ival = Segs::Pattern::DUP;
-                } else if (output.back() == "tra" || output.back() == "translocation") {
-                    e.ival = Segs::Pattern::TRA;
-                } else if (output.back() == "paired") {
-                    e.ival = Property::PAIRED;
-                } else if (output.back() == "proper-pair") {
-                    e.ival = Property::PROPER_PAIR;
-                } else if (output.back() == "unmapped") {
-                    e.ival = Property::UNMAP;
-                } else if (output.back() == "munmap") {
-                    e.ival = Property::MUNMAP;
-                } else if (output.back() == "reverse") {
-                    e.ival = Property::REVERSE;
-                } else if (output.back() == "mreverse") {
-                    e.ival = Property::MREVERSE;
-                } else if (output.back() == "read1") {
-                    e.ival = Property::READ1;
-                } else if (output.back() == "read2") {
-                    e.ival = Property::READ2;
-                } else if (output.back() == "secondary") {
-                    e.ival = Property::SECONDARY;
-                } else if (output.back() == "qcfail") {
-                    e.ival = Property::QCFAIL;
-                } else if (output.back() == "duplicate") {
-                    e.ival = Property::FLAG_DUPLICATE;
-                } else if (output.back() == "supplementary") {
-                    e.ival = Property::SUPPLEMENTARY;
-                } else {
-                    out << "Right-hand side value must be an integer or named-value: " << output[2] << std::endl;
-                    out << "Named values can be one of: paired, proper-pair, unmapped, munmap, reverse, mreverse, read1, read2, secondary, qcfail, dup, supplementary\n";
-                    return -1;
+            if (is_none) {
+                e.ival = INT_MAX;
+            } else {
+                try {
+                    e.ival = std::stoi(output.back());
+                } catch (...) {
+                    if (output.back() == "del" || output.back() == "deletion") {
+                        e.ival = Segs::Pattern::DEL;
+                    } else if (output.back() == "inv_f" || output.back() == "inversion_forward") {
+                        e.ival = Segs::Pattern::INV_F;
+                    } else if (output.back() == "inv_r" || output.back() == "inversion_reverse") {
+                        e.ival = Segs::Pattern::INV_R;
+                    } else if (output.back() == "dup" || output.back() == "duplication") {
+                        e.ival = Segs::Pattern::DUP;
+                    } else if (output.back() == "tra" || output.back() == "translocation") {
+                        e.ival = Segs::Pattern::TRA;
+                    } else if (output.back() == "paired") {
+                        e.ival = Property::PAIRED;
+                    } else if (output.back() == "proper-pair") {
+                        e.ival = Property::PROPER_PAIR;
+                    } else if (output.back() == "unmapped") {
+                        e.ival = Property::UNMAP;
+                    } else if (output.back() == "munmap") {
+                        e.ival = Property::MUNMAP;
+                    } else if (output.back() == "reverse") {
+                        e.ival = Property::REVERSE;
+                    } else if (output.back() == "mreverse") {
+                        e.ival = Property::MREVERSE;
+                    } else if (output.back() == "read1") {
+                        e.ival = Property::READ1;
+                    } else if (output.back() == "read2") {
+                        e.ival = Property::READ2;
+                    } else if (output.back() == "secondary") {
+                        e.ival = Property::SECONDARY;
+                    } else if (output.back() == "qcfail") {
+                        e.ival = Property::QCFAIL;
+                    } else if (output.back() == "duplicate") {
+                        e.ival = Property::FLAG_DUPLICATE;
+                    } else if (output.back() == "supplementary") {
+                        e.ival = Property::SUPPLEMENTARY;
+                    } else {
+                        out << "Right-hand side value must be an integer or named-value: " << output[2] << std::endl;
+                        out << "Named values can be one of: paired, proper-pair, unmapped, munmap, reverse, mreverse, read1, read2, secondary, qcfail, dup, supplementary\n";
+                        return -1;
+                    }
                 }
             }
-        } else if (lhs >= 4000) {
+        } else if (lhs >= 4000) {  // String-like
             e.property = lhs;
             e.op = mid;
-            e.sval = output.back();
+            if (is_none) {
+                e.sval = "''";
+            } else {
+                e.sval = output.back();
+            }
+            e.numeric_like = false;
+            if (lhs == SEQ_RC) {  // Reverse-complement value
+                e.sval = reverseComplement(output.back());
+            }
         } else {
             out << "Left-hand side operation not available: " << output[0] << std::endl; return -1;
         }
@@ -456,25 +489,29 @@ namespace Parse {
         }
     }
 
-    void getStrTag(const char* tag, std::string &str_val, const Segs::Align &aln) {
+    void getStrTag(const char* tag, std::string& str_val, const Segs::Align& aln, bool& exists) {
         const uint8_t *tag_ptr;
         tag_ptr = bam_aux_get(aln.delegate, tag);
         if (tag_ptr == nullptr) {
+            exists = false;
+            str_val = "''";
             return;
         }
         str_val = std::string(bam_aux2Z(tag_ptr));
     }
 
-    void getIntTag(const char* tag, int &int_val, const Segs::Align &aln) {
+    void getIntTag(const char* tag, int& int_val, const Segs::Align& aln, bool& exists) {
         const uint8_t *tag_ptr;
         tag_ptr = bam_aux_get(aln.delegate, tag);
         if (tag_ptr == nullptr) {
+            exists = false;
+            int_val = INT_MAX;
             return;
         }
         int_val = bam_aux2i(tag_ptr);
     }
 
-    void getCigarStr(std::string &str_val, const Segs::Align &aln) {
+    void getCigarStr(std::string& str_val, const Segs::Align& aln) {
         uint32_t l, cigar_l, op, k;
         uint32_t *cigar_p;
         cigar_l = aln.delegate->core.n_cigar;
@@ -502,12 +539,10 @@ namespace Parse {
 
     bool Parser::eval(const Segs::Align& aln, const sam_hdr_t* hdr, int bamIdx, int regionIdx) {
 
-        bool block_result = true;
-
         if (bamIdx >= 0 && !targetIndexes.empty() && targetIndexes[bamIdx][regionIdx] == 0) {
             return true;
         }
-
+        bool block_result = true;
         if (!evaluations_block.empty()) {
             for (auto &e : evaluations_block) {
                 int int_val = 0;
@@ -529,7 +564,6 @@ namespace Parse {
                         break;
                     case TLEN:
                         int_val = aln.delegate->core.isize;
-
                         break;
                     case ABS_TLEN:
                         int_val = std::abs(aln.delegate->core.isize);
@@ -545,6 +579,7 @@ namespace Parse {
                         break;
                     case REF_END:
                         int_val = bam_endpos(aln.delegate);
+                        break;
                     case PNEXT:
                         int_val = aln.delegate->core.mpos;
                         break;
@@ -563,73 +598,73 @@ namespace Parse {
                         int_val = aln.delegate->core.mtid;
                         break;
                     case RG:
-                        getStrTag("RG", str_val, aln);
+                        getStrTag("RG", str_val, aln, e.exists);
                         break;
                     case BC:
-                        getStrTag("BC", str_val, aln);
+                        getStrTag("BC", str_val, aln, e.exists);
                         break;
                     case LB:
-                        getStrTag("LB", str_val, aln);
+                        getStrTag("LB", str_val, aln, e.exists);
                         break;
                     case MD:
-                        getStrTag("MD", str_val, aln);
+                        getStrTag("MD", str_val, aln, e.exists);
                         break;
                     case PU:
-                        getStrTag("PU", str_val, aln);
+                        getStrTag("PU", str_val, aln, e.exists);
                         break;
                     case SA:
-                        getStrTag("SA", str_val, aln);
+                        getStrTag("SA", str_val, aln, e.exists);
                         break;
                     case MC:
-                        getStrTag("MC", str_val, aln);
+                        getStrTag("MC", str_val, aln, e.exists);
                         break;
                     case BX:
-                        getStrTag("BX", str_val, aln);
+                        getStrTag("BX", str_val, aln, e.exists);
                         break;
                     case RX:
-                        getStrTag("RX", str_val, aln);
+                        getStrTag("RX", str_val, aln, e.exists);
                         break;
                     case MI:
-                        getStrTag("MI", str_val, aln);
+                        getStrTag("MI", str_val, aln, e.exists);
                         break;
                     case NM:
-                        getIntTag("NM", int_val, aln);
+                        getIntTag("NM", int_val, aln, e.exists);
                         break;
                     case CM:
-                        getIntTag("CM", int_val, aln);
+                        getIntTag("CM", int_val, aln, e.exists);
                         break;
                     case FI:
-                        getIntTag("FI", int_val, aln);
+                        getIntTag("FI", int_val, aln, e.exists);
                         break;
                     case HO:
-                        getIntTag("HO", int_val, aln);
+                        getIntTag("HO", int_val, aln, e.exists);
                         break;
                     case MQ:
-                        getIntTag("MQ", int_val, aln);
+                        getIntTag("MQ", int_val, aln, e.exists);
                         break;
                     case SM:
-                        getIntTag("SM", int_val, aln);
+                        getIntTag("SM", int_val, aln, e.exists);
                         break;
                     case TC:
-                        getIntTag("TC", int_val, aln);
+                        getIntTag("TC", int_val, aln, e.exists);
                         break;
                     case UQ:
-                        getIntTag("UQ", int_val, aln);
+                        getIntTag("UQ", int_val, aln, e.exists);
                         break;
                     case AS:
-                        getIntTag("AS", int_val, aln);
+                        getIntTag("AS", int_val, aln, e.exists);
                         break;
                     case HP:
-                        getIntTag("HP", int_val, aln);
+                        getIntTag("HP", int_val, aln, e.exists);
                         break;
                     case CIGAR:
-                         getCigarStr(str_val, aln);
-                         break;
+                        getCigarStr(str_val, aln);
+                        break;
                     default:
                         break;
 
                 }
-                if (e.property == SEQ) {
+                if (e.property == SEQ || e.property == SEQ_RC) {
                     switch (e.op) {
                         case EQ: this_result = str_val == e.sval; break;
                         case NE: this_result = str_val != e.sval; break;
@@ -638,7 +673,7 @@ namespace Parse {
                         default: break;
                     }
 
-                } else if (str_val.empty()) {
+                } else if (e.numeric_like) {
                     switch (e.op) {
                         case GT: this_result = int_val > e.ival; break;
                         case GE: this_result = int_val >= e.ival; break;
@@ -649,7 +684,7 @@ namespace Parse {
                         case AND: this_result = int_val & e.ival; break;
                         default: break;
                     }
-                } else {
+                } else {  // str type
                     switch (e.op) {
                         case EQ: this_result = str_val == e.sval; break;
                         case NE: this_result = str_val != e.sval; break;
@@ -660,13 +695,15 @@ namespace Parse {
                 }
 
                 if (orBlock && this_result) {
-                    return this_result;
+                    return this_result;  // Early return for OR when true found
+                } else if (!orBlock && !this_result) {
+                    return false;        // Early return for AND when false found
                 } else {
-                    block_result &= this_result;
+                    block_result &= this_result; // Accumulate
                 }
             }
         }
-        return block_result;
+        return orBlock ? false : block_result;
     }
 
 
