@@ -168,27 +168,57 @@ namespace Term {
                          "            filter mapq >= 20\n"
                          "            filter flag & 2048\n"
                          "            filter seq contains TTAGGG\n\n"
+                         "        Properties are interpreted as either Numeric-like or String-like.\n"
                          "        Here are a list of '{property}' values you can use:\n"
-                         "             maps, flag, ~flag, name, tlen, abs-tlen, rnext, pos, ref-end, pnext, seq, seq-len,\n"
-                         "             RG, BC, BX, RX, LB, MD, MI, PU, SA, MC, NM, CM, FI, HO, MQ, SM, TC, UQ, AS\n\n"
-                         "        These can be combined with '{operator}' values:\n"
-                         "             &, ==, !=, >, <, >=, <=, eq, ne, gt, lt, ge, le, contains, omit\n\n"
+                         "        --> 'Numeric' properties:\n"
+                         "             mapq       # Mapping quality\n"
+                         "             flag       # Bit flag\n"
+                         "             ~flag      # Bit-wise NOT flag\n"
+                         "             tlen       # Template-length\n"
+                         "             abs-tlen   # Absolute template-length\n"
+                         "             pos        # Alignment start position\n"
+                         "             ref-end    # Alignment end position\n"
+                         "             pnext      # Position of mate\n"
+                         "             seq-len    # Sequence length\n"
+                         "             NM, CM, FI, HO, MQ, SM, TC, UQ, AS, HP  # Bam-tags\n\n"
+                         "         --> 'String' properties:\n"
+                         "             name       # Read name\n"
+                         "             rname      # Chromosome name\n"
+                         "             rnext      # Chromosome name of mate\n"
+                         "             cigar      # Cigar-string of alignment\n"
+                         "             seq        # Sequence of this alignment\n"
+                         "             seq-rc     # Reverse-complement sequence of this alignment\n"
+                         "             RG, BC, BX, RX, LB, MD, MI, PU, SA, MC  # Bam-tags\n\n"
+                         "        Numeric types can be combined with operators:\n"
+                         "            ==         # Equal to; or use '=' or 'eq'\n"
+                         "            !=         # Not equal to; or 'ne'\n"
+                         "            >          # Greater than; gt\n"
+                         "            <          # Less than; lt\n"
+                         "            >=         # Greater-or-equal; ge\n"
+                         "            <=         # Less-or-equal; le\n\n"
+                         "        String typed can be combined with operators:\n"
+                         "            ==         # Equal to; or use '=' or 'eq'\n"
+                         "            !=         # Not equal to; or 'ne'\n"
+                         "            contains   # String contains substring\n"
+                         "            omit       # Removes read if string contains substring\n\n"
+                         "        If you want to filter using missing values, you can use 'none' or '', e.g:\n"
+                         "            filter SA == none  # Only reads with no SA tag are kept\n\n"
                          "        Reads can be filtered on their mapping orientation/pattern e.g:\n"
-                         "             filter pattern == del    # deletion-like pattern\n"
-                         "             filter pattern == inv_f  # inversion-forward\n"
-                         "             filter pattern == inv_f  # inversion-reverse\n"
-                         "             filter pattern != tra    # translocation\n\n"
+                         "            filter pattern == del    # deletion-like pattern\n"
+                         "            filter pattern == inv_f  # inversion-forward\n"
+                         "            filter pattern == inv_f  # inversion-reverse\n"
+                         "            filter pattern != tra    # translocation\n\n"
                          "        Bitwise flags can also be applied with named values:\n"
-                         "             paired, proper-pair, unmapped, munmap, reverse, mreverse, read1, read2, secondary, dup, supplementary\n\n"
-                         "             filter paired\n"
-                         "             filter read1\n\n"
+                         "            paired, proper-pair, unmapped, munmap, reverse, mreverse, read1, read2, secondary, dup, supplementary\n\n"
+                         "            filter paired\n"
+                         "            filter read1\n\n"
                          "        Expressions can be chained together providing all expressions are 'AND' or 'OR' blocks:\n"
-                         "             filter mapq >= 20 and mapq < 30\n"
-                         "             filter mapq >= 20 or flag & supplementary\n\n"
+                         "            filter mapq >= 20 and mapq < 30\n"
+                         "            filter mapq >= 20 or flag & supplementary\n\n"
                          "        Finally, you can apply filters to specific panels using array indexing notation:\n"
-                         "             filter mapq > 0 [:, 0]   # All rows, column 0 (all bams, first region only)\n"
-                         "             filter mapq > 0 [0, :]   # Row 0, all columns (the first bam only, all regions)\n"
-                         "             filter mapq > 0 [1, -1]  # Row 1, last column\n\n";
+                         "            filter mapq > 0 [:, 0]   # All rows, column 0 (all bams, first region only)\n"
+                         "            filter mapq > 0 [0, :]   # Row 0, all columns (the first bam only, all regions)\n"
+                         "            filter mapq > 0 [1, -1]  # Row 1, last column\n\n";
         } else if (s == "find" || s == "f") {
             out << "    Find a read with name.\n        All alignments with the same name will be highlighted with a black border\n    Examples:\n        'find D00360:18:H8VC6ADXX:1:1107:5538:24033'\n\n";
         } else if (s == "goto") {
