@@ -16,6 +16,8 @@
     #if defined(__APPLE__)
         #include <CoreText/CoreText.h>
         #include "include/ports/SkFontMgr_mac_ct.h"
+    #elif defined(_WIN32) || defined(_WIN64)
+        #include "include/ports/SkTypeface_win.h"
     #else
         #include <fontconfig/fontconfig.h>
         #include "include/ports/SkFontMgr_fontconfig.h"
@@ -1182,6 +1184,11 @@ namespace Themes {
             }
 
         }
+#elif defined(_WIN32) || defined(_WIN64)
+        fontMgr = SkFontMgr_New_DirectWrite();
+        if (!fontMgr) {
+            std::cerr << "Error: failed to create DirectWrite font manager on Windows\n";
+        }
 #else
         // Use FontConfig for all other platforms
         FcInit();
